@@ -3,13 +3,14 @@ BEGIN {
   $POE::Quickie::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Quickie::VERSION = '0.08';
+  $POE::Quickie::VERSION = '0.09';
 }
 
 use strict;
 use warnings;
 use Carp 'croak';
 use POE;
+use POE::Filter::Stream;
 use POE::Wheel::Run;
 
 require Exporter;
@@ -47,6 +48,7 @@ sub _create_session {
                 _create_wheel
                 _child_signal
                 _child_timeout
+                _child_stdin
                 _child_stdout
                 _child_stderr
                 _killall
@@ -115,6 +117,8 @@ sub _create_wheel {
     my $wheel;
     eval {
         $wheel = POE::Wheel::Run->new(
+            StdinFilter => POE::Filter::Stream->new(),
+            StdinEvent  => '_child_stdin',
             StdoutEvent => '_child_stdout',
             StderrEvent => '_child_stderr',
             Program     => $program,
@@ -142,9 +146,8 @@ sub _create_wheel {
     $self->{wheels}{$wheel->ID}{args} = $args;
     $self->{wheels}{$wheel->ID}{alive} = 2;
 
-    if ($args->{Input}) {
+    if (defined $args->{Input}) {
         $wheel->put($args->{Input});
-        $wheel->shutdown_stdin();
     }
 
     if (defined $args->{Timeout}) {
@@ -203,6 +206,12 @@ sub _child_timeout {
     return;
 }
 
+sub _child_stdin {
+    my ($self, $id) = @_[OBJECT, ARG0];
+    $self->{wheels}{$id}{obj}->shutdown_stdin();
+    return;
+}
+
 sub _child_stdout {
     my ($kernel, $self, $output, $id) = @_[KERNEL, OBJECT, ARG0, ARG1];
 
@@ -477,7 +486,9 @@ POE::Wheel::Run.
 
 B<'Input'> (optional), a string containing the input to the program. This
 string, if provided, will be sent immediately to the program, and its
-stdin will then be shut down.
+stdin will then be shut down. Note: no processing will be done on the data
+before it is sent, so make sure you include newlines where needed if the
+program requires them.
 
 B<'StdoutEvent'> (optional), the event for delivering lines from the
 program's STDOUT. If you don't supply this, they will be printed to the main
